FirebaseGitHubReAuthProvider class

An AuthQuery for GitHub's OAuth authentication on Firebase.

FirebaseにおけるGitHubのOAuth認証を行うためのAuthQuery

Inheritance
  • Object
  • AuthProvider
  • ReAuthProvider
  • FirebaseSnsReAuthProvider
  • FirebaseGitHubReAuthProvider

Constructors

FirebaseGitHubReAuthProvider()
An AuthQuery for GitHub's OAuth authentication on Firebase.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
providerId String
ID that defines the provider's process.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

authProvider() → AuthProvider
Obtain an authentication provider for SNS re-authentication in Firebase.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onReAuthenticatedWithProvider(UserCredential credential) Future<void>
Called when a user re-authenticates with a provider.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited